<?php

namespace WilokeThreeDSlider\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use WilokeThreeDSlider\Shared\HtmlHelper;

class ThreeDSliderWidget extends Widget_Base
{

	public function get_style_depends()
	{
		return [WILOKE_3D_SLIDER_ID];
	}

	public function get_script_depends()
	{
		return [WILOKE_3D_SLIDER_ID];
	}

	public function get_name()
	{
		return WILOKE_3D_SLIDER_ID . '-settings';
	}

	public function get_title()
	{
		return "Wiloke 3D Slider";
	}

	public function get_icon()
	{
		return 'fa-regular fa-sensor';
	}

	public function get_categories()
	{
		return ['wiloke-category'];
	}

	protected function _register_controls()
	{
		$this->start_controls_section(
			'wiloke_3d_slider_settings_section_content',
			[
				'label' => esc_html__('Settings', 'wiloke-3d-slider'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'gallery',
			[
				'label' => esc_html__('Gallery', 'wiloke-3d-slider'),
				'type'  => Controls_Manager::GALLERY
			]
		);

		$this->add_control(
			'slider_interval',
			[
				'label'       => esc_html__('Slider Interval', 'wiloke-3d-slider'),
				'description' => esc_html__('How long do you want to show each slide? Unit: milliseconds', 'wiloke-3d-slider'),
				'type'        => Controls_Manager::NUMBER,
				'default'     => 2500
			]
		);

		$this->add_control(
			'container_height',
			[
				'label'       => esc_html__('Container Height', 'wiloke-3d-slider'),
				'description' => esc_html__('Set the height of 3d slider', 'wiloke-3d-slider'),
				'type'        => Controls_Manager::NUMBER,
				'default'     => 500
			]
		);

		$this->add_control(
			'container_width',
			[
				'label'       => esc_html__('Container Width', 'wiloke-3d-slider'),
				'description' => esc_html__('Set the width of 3d slider', 'wiloke-3d-slider'),
				'type'        => Controls_Manager::NUMBER,
				'default'     => 700
			]
		);

		$this->add_control(
			'perspective',
			[
				'label'       => esc_html__('Perspective', 'wiloke-3d-slider'),
				'description' => esc_html__('The perspective property defines how far the object is away from the user. So, a lower value will result in a more intensive 3D effect than a higher value.',
					'wiloke-3d-slider'),
				'type'        => Controls_Manager::NUMBER,
				'default'     => 500
			]
		);

		$this->add_control(
			'description',
			[
				'label' => esc_html__('Description', 'wiloke-3d-slider'),
				'type'  => Controls_Manager::WYSIWYG
			]
		);


		$this->end_controls_section();
	}

	protected function render()
	{
		$aSettings = $this->get_settings_for_display();

		if (empty($aSettings)) {
			return;
		}

		if (empty($aSettings["gallery"])) {
			return;
		}

		?>
		<div class="wil-3d-slider-wrapper">
			<?php if (!empty($aSettings["description"])) : ?>
				<div class="<?php echo HtmlHelper::autoPrefix("description"); ?>">
					<?php echo wp_kses_post($aSettings["description"]); ?>
				</div>
			<?php endif; ?>
			<div class="<?php echo HtmlHelper::autoPrefix("img-container"); ?>"
			     data-interval="<?php echo esc_attr($aSettings["slider_interval"]); ?>"
			     style="--wil-perspective:<?php echo esc_attr($aSettings["perspective"]); ?>px;
				     --wil-width: <?php echo esc_attr($aSettings["container_width"]); ?>;
				     --wil-height: <?php echo esc_attr($aSettings["container_height"]); ?>"
			>
				<?php
				foreach ($aSettings["gallery"] as $aGallery) {
					$url = !empty($aGallery["id"]) ? wp_get_attachment_image_url($aGallery["id"], "large") : "";
					$url = !empty($url) ? $url : $aGallery["url"];
					$alt = get_post_meta($aGallery["id"], '_wp_attachment_image_alt', true);

					$aImage = [
						"url" => $url,
						"alt" => $alt
					];

					$aGallery["image"] = $aImage;

					HtmlHelper::renderItem($aGallery);
				}
				?>
			</div>
		</div>
		<?php
	}
}
